@@ -2,8 +2,8 @@ divisorsBig <- function(v, namedList = FALSE) {
     GetDivisorsC(v, namedList, NULL, pkgEnv$nThreads)
 }
 
-quadraticSieve <- function(n, showStats = FALSE) {
-    QuadraticSieveContainer(n, showStats, NULL, pkgEnv$nThreads)
+quadraticSieve <- function(n, showStats = FALSE, nThreads = NULL, skipExtPolRho = FALSE) {
+    QuadraticSieveContainer(n, showStats, nThreads, pkgEnv$nThreads, skipExtPolRho)
 }
 
 stdThreadMax <- function() {
@@ -14,4 +14,4 @@ stdThreadMax <- function() {
     }
     
     nThreads
-}
\ No newline at end of file
+}
