@@ -8,7 +8,6 @@
 #include <numeric>
 #include <cmath>
 
-constexpr unsigned long int oneThousand = 1000u;
 constexpr double Significand53 = 9007199254740991.0;
 constexpr int L1Cache = 32768;
 
@@ -19,8 +18,6 @@ using hash64mpz = std::unordered_map<std::uint64_t, mpz_class>;
 std::vector<std::size_t> SetSieveDist(const std::vector<int> &facBase,
                                       const mpz_class &myNum);
 
-std::vector<std::uint8_t> MyIntToBit(std::size_t x, std::size_t dig);
-
 std::vector<int> GetPrimesQuadRes(const mpz_class &myN, double LimB, double fudge1,
                                   double sqrLogLog, std::size_t myTarget);
 
@@ -32,8 +29,7 @@ void SinglePoly(const std::vector<std::size_t> &SieveDist,
                 std::vector<uint64_t> &largeCoFactors,
                 std::vector<mpz_class> &partialInterval,
                 const mpz_class &NextPrime, const mpz_class &LowBound,
-                const mpz_class &myNum, std::size_t &nPartial,
-                std::size_t &nSmooth, int theCut,int DoubleLenB,
+                const mpz_class &myNum, int theCut,int DoubleLenB,
                 int mpzFacSize, int vecMaxSize, std::size_t strt);
 
 #endif
